@@ -39,7 +39,7 @@ class DriveSerializer(serializers.ModelSerializer):
 
 
 class LinuxVolumeSerializer(serializers.ModelSerializer):
-    filesystem = NestedFilesystemSerializer(required=False, allow_null=True)
+    fs = NestedFilesystemSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LinuxVolume
@@ -57,7 +57,7 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
 
 
 class WindowsVolumeSerializer(serializers.ModelSerializer):
-    filesystem = NestedFilesystemSerializer(required=False, allow_null=True)
+    fs = NestedFilesystemSerializer(required=False, allow_null=True)
 
     class Meta:
         model = WindowsVolume
