@@ -4,6 +4,8 @@ from netbox_storage.api.views import (
     NetboxStorageRootView,
     DriveViewSet,
     FilesystemViewSet,
+    LinuxVolumeViewSet,
+    WindowsVolumeViewSet,
 )
 
 router = NetBoxRouter()
@@ -11,7 +13,7 @@ router.APIRootView = NetboxStorageRootView
 
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
-router.register("linuxvolume", DriveViewSet)
-router.register("windowsvolume", FilesystemViewSet)
+router.register("linuxvolume", LinuxVolumeViewSet)
+router.register("windowsvolume", WindowsVolumeViewSet)
 
 urlpatterns = router.urls
